starcluster.templates

Package starcluster :: Package templates |
[hide private]
[frames] | no frames]

# Package templates

source code

Submodules | [hide private]
starcluster.templates.config starcluster.templates.sge starcluster.templates.user_msgs

Functions | [hide private]
get_resource(pkg_data_path, stream=True) | source code

Variables | [hide private]
| loader = `jinja2.Environment(loader= jinja2.PrefixLoader({'web'`...``
| __package__ = ``'``starcluster.templates``'``

Variables Details | [hide private]

  ### loader Value:
      jinja2.Environment(loader= jinja2.PrefixLoader({'web': jinja2.PackageL
      oader('starcluster.templates', 'web'),}))